# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from ._enums import *
from .access_token import *
from .agent_pool import *
from .deployment_schedule import *
from .deployment_settings import *
from .drift_schedule import *
from .environment import *
from .org_access_token import *
from .provider import *
from .stack_tag import *
from .team import *
from .team_access_token import *
from .team_environment_permission import *
from .team_stack_permission import *
from .ttl_schedule import *
from .webhook import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_pulumiservice.config as __config
    config = __config
else:
    config = _utilities.lazy_import('pulumi_pulumiservice.config')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "pulumiservice",
  "mod": "index",
  "fqn": "pulumi_pulumiservice",
  "classes": {
   "pulumiservice:index:AccessToken": "AccessToken",
   "pulumiservice:index:AgentPool": "AgentPool",
   "pulumiservice:index:DeploymentSchedule": "DeploymentSchedule",
   "pulumiservice:index:DeploymentSettings": "DeploymentSettings",
   "pulumiservice:index:DriftSchedule": "DriftSchedule",
   "pulumiservice:index:Environment": "Environment",
   "pulumiservice:index:OrgAccessToken": "OrgAccessToken",
   "pulumiservice:index:StackTag": "StackTag",
   "pulumiservice:index:Team": "Team",
   "pulumiservice:index:TeamAccessToken": "TeamAccessToken",
   "pulumiservice:index:TeamEnvironmentPermission": "TeamEnvironmentPermission",
   "pulumiservice:index:TeamStackPermission": "TeamStackPermission",
   "pulumiservice:index:TtlSchedule": "TtlSchedule",
   "pulumiservice:index:Webhook": "Webhook"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "pulumiservice",
  "token": "pulumi:providers:pulumiservice",
  "fqn": "pulumi_pulumiservice",
  "class": "Provider"
 }
]
"""
)



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['ProviderArgs', 'Provider']

@pulumi.input_type
class ProviderArgs:
    def __init__(__self__, *,
                 access_token: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Provider resource.
        :param pulumi.Input[str] access_token: Access Token to authenticate with Pulumi Cloud.
        """
        if access_token is None:
            access_token = (_utilities.get_env('PULUMI_ACCESS_TOKEN') or '')
        if access_token is not None:
            pulumi.set(__self__, "access_token", access_token)

    @property
    @pulumi.getter(name="accessToken")
    def access_token(self) -> Optional[pulumi.Input[str]]:
        """
        Access Token to authenticate with Pulumi Cloud.
        """
        return pulumi.get(self, "access_token")

    @access_token.setter
    def access_token(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "access_token", value)


class Provider(pulumi.ProviderResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_token: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Create a Pulumiservice resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] access_token: Access Token to authenticate with Pulumi Cloud.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[ProviderArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a Pulumiservice resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param ProviderArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProviderArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_token: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProviderArgs.__new__(ProviderArgs)

            if access_token is None:
                access_token = (_utilities.get_env('PULUMI_ACCESS_TOKEN') or '')
            __props__.__dict__["access_token"] = access_token
        super(Provider, __self__).__init__(
            'pulumiservice',
            resource_name,
            __props__,
            opts)

